# Exploring the CALM Brain Resource with almirah

## Load the dataset


```python
from almirah import Dataset
```
```python
Dataset.options()
```

    [<Dataset name: 'calm-brain'>]
    
```python
ds = Dataset(name="calm-brain")
ds.components
```

    [<Layout root: '/path/to/data'>,
     <Layout root: '/path/to/genome'>,
     <Database url: 'request:calm-brain@https://www.calm-brain.ncbs.res.in/db-request/'>]

## Quering layouts

```python
lay = ds.components[0]
print(lay)
len(lay.files)
```

    <Layout root: '/path/to/data'>

    42652

```python
from almirah import Tag

tags = Tag.options()
len(tags)
```

    1589
    
```python
tags_names_possible = {tag.name for tag in tags}
tags_names_possible
```

    {'acquisition',
     'datatype',
     'direction',
     'extension',
     'run',
     'sample',
     'session',
     'space',
     'subject',
     'suffix',
     'task'}

```python
Tag.options(name="datatype")
```

    [<Tag datatype: 'anat'>,
     <Tag datatype: 'dwi'>,
     <Tag datatype: 'eeg'>,
     <Tag datatype: 'eyetrack'>,
     <Tag datatype: 'fmap'>,
     <Tag datatype: 'func'>,
     <Tag datatype: 'genome'>,
     <Tag datatype: 'nirs'>]

```python
files = lay.query(datatype="eeg")
len(files)
```

    15821

```python
file = files[0]
file.rel_path
```

    'sub-D0828/ses-101/eeg/sub-D0828_ses-101_task-auditoryPCP_run-01_events.json'

```python
file.tags
```

    {'datatype': 'eeg', 'extension': '.json', 'run': '01', 'session': '101', 'subject': 'D0828', 'suffix': 'events', 'task': 'auditoryPCP'}

## Querying databases

```python
db = ds.components[2]
db
```

    <Database url: 'request:calm-brain@https://www.calm-brain.ncbs.res.in/db-request/'>

```python
db.connect("username", "password")
df = db.query(table="presenting_disorders")
df[["subject", "session", "addiction"]].head()
```

<div>
<style scoped>
    .dataframe tbody tr th:only-of-type {
        vertical-align: middle;
    }
    .dataframe tbody tr th {
        vertical-align: top;
    }
    .dataframe thead th {
        text-align: right;
    }
</style>
<table border="1" class="dataframe">
  <thead>
    <tr style="text-align: right;">
      <th></th>
      <th>subject</th>
      <th>session</th>
      <th>addiction</th>
    </tr>
  </thead>
  <tbody>
    <tr>
      <th>0</th>
      <td>D0019</td>
      <td>101</td>
      <td>0</td>
    </tr>
    <tr>
      <th>1</th>
      <td>D0019</td>
      <td>111</td>
      <td>0</td>
    </tr>
    <tr>
      <th>2</th>
      <td>D0020</td>
      <td>101</td>
      <td>0</td>
    </tr>
    <tr>
      <th>3</th>
      <td>D0020</td>
      <td>111</td>
      <td>&lt;NA&gt;</td>
    </tr>
    <tr>
      <th>4</th>
      <td>D0021</td>
      <td>101</td>
      <td>0</td>
    </tr>
  </tbody>
</table>
</div>

## Generating summaries

```python
anat_subject_tags = ds.query(returns="subject", datatype="anat")
anat_subjects = {subject for t in anat_subject_tags for subject in t}
len(anat_subjects)
```

    699

```python
eyetrack_subject_tags = ds.query(returns="subject", datatype="eyetrack")
eyetrack_subjects = {subject for t in eyetrack_subject_tags for subject in t}
len(eyetrack_subjects)
```

    1075    

```python
df = db.query(table="subjects")
len(df)
```

    2276

```python
df = db.query(table="modified_kuppuswamy_socioeconomic_scale")
len(df)
```

    1444

