# Importing Eye tracking data with MNE-Python

```python
import mne
import matplotlib.pyplot as plt

from almirah import Layout

mne.set_log_level(False)
```

```python
lay = Layout(root="/path/to/data", specification_name="bids")
lay
```

    <Layout root: '/path/to/data'>

```python
files = lay.query(datatype="eyetrack", extension=".asc")
len(files)
```

    3632

```python
file = lay.query(subject="D0019", datatype="eyetrack", task="FIX", extension=".asc")[0]

print(file.rel_path)
```

    sub-D0019/ses-111/eyetrack/sub-D0019_ses-111_task-FIX_run-01_eyetrack.asc

```python
raw = mne.io.read_raw_eyelink(file.path, create_annotations=["blinks"])
custom_scalings = dict(eyegaze=1e3)
raw.pick(picks="eyetrack").plot(scalings=custom_scalings)
plt.close()
```
    
![png](../images/eyetrack/eye-position-plot.png)
    
```python
raw
```

<details open>
  <summary><strong>General</strong></summary>
  **Measurement date:** January 01, 2009 00:03:33 GMT  
  **Experimenter:** Unknown  
  **Participant:** Unknown  
</details>

<details open>
  <summary><strong>Channels</strong></summary>
  **Digitized points:** Not available  
  **Good channels:** 2 Eye-tracking (Gaze position), 1 Eye-tracking (Pupil size)  
  **Bad channels:** None  
  **EOG channels:** Not available  
  **ECG channels:** Not available  
</details>

<details open>
  <summary><strong>Data</strong></summary>
  **Sampling frequency:** 1000.00 Hz  
  **Highpass:** 0.00 Hz  
  **Lowpass:** 500.00 Hz  
  **Filenames:** sub-D0019_ses-111_task-FIX_run-01_eyetrack.asc  
  **Duration:** 00:01:11 (HH:MM:SS)  
</details>

```python
raw.ch_names
```

    ['xpos_left', 'ypos_left', 'pupil_left']

```python
raw["xpos_left"]
```

    (array([[510.2, 510.1, 509.9, ..., 454.4, 454.8, 455.5]]),
     array([0.0000e+00, 1.0000e-03, 2.0000e-03, ..., 7.0556e+01, 7.0557e+01,
            7.0558e+01]))

